..
   Copyright (C) 2024 Roberto Rossini <roberros@uio.no>
   SPDX-License-Identifier: MIT

Generic API
===========

.. py:module:: hictkpy
.. py:currentmodule:: hictkpy


.. autofunction:: is_cooler
.. autofunction:: is_mcool_file
.. autofunction:: is_scool_file

.. autofunction:: is_hic

.. autoclass:: MultiResFile
   :members:
   :special-members: __init__

.. autoclass:: File
   :members:
   :special-members: __init__

.. autoclass:: PixelSelector
   :members:
